[llvm-branch-commits] [llvm-gcc-branch] r83126 - in /llvm-gcc-4.2/branches/eh-experiment/gcc: llvm-convert.cpp llvm-internal.h
Bill Wendling
isanbard at gmail.com
Tue Sep 29 17:21:11 PDT 2009
Author: void
Date: Tue Sep 29 19:21:11 2009
New Revision: 83126
URL: http://llvm.org/viewvc/llvm-project?rev=83126&view=rev
Log:
s/eh_personality_/eh_landingpad_/.
Modified:
llvm-gcc-4.2/branches/eh-experiment/gcc/llvm-convert.cpp
llvm-gcc-4.2/branches/eh-experiment/gcc/llvm-internal.h
Modified: llvm-gcc-4.2/branches/eh-experiment/gcc/llvm-convert.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm-gcc-4.2/branches/eh-experiment/gcc/llvm-convert.cpp?rev=83126&r1=83125&r2=83126&view=diff
==============================================================================
--- llvm-gcc-4.2/branches/eh-experiment/gcc/llvm-convert.cpp (original)
+++ llvm-gcc-4.2/branches/eh-experiment/gcc/llvm-convert.cpp Tue Sep 29 19:21:11 2009
@@ -177,7 +177,7 @@
ExceptionValue = 0;
ExceptionSelectorValue = 0;
- FuncEHPersonality = 0;
+ FuncEHLandingPad = 0;
FuncEHException = 0;
FuncEHSelector = 0;
FuncEHGetTypeID = 0;
@@ -607,8 +607,8 @@
// Emit gcroot intrinsic if arg has attribute
if (POINTER_TYPE_P(TREE_TYPE(Args))
- && lookup_attribute ("gcroot", TYPE_ATTRIBUTES(TREE_TYPE(Args))))
- EmitTypeGcroot(Tmp, Args);
+ && lookup_attribute ("gcroot", TYPE_ATTRIBUTES(TREE_TYPE(Args))))
+ EmitTypeGcroot(Tmp, Args);
Client.setName(Name);
Client.setLocation(Tmp);
@@ -1455,7 +1455,7 @@
Fn->setGC("shadow-stack");
Function *gcrootFun = Intrinsic::getDeclaration(TheModule,
- Intrinsic::gcroot);
+ Intrinsic::gcroot);
// The idea is that it's a pointer to type "Value"
// which is opaque* but the routine expects i8** and i8*.
@@ -1920,10 +1920,10 @@
ExceptionSelectorValue = CreateTemporary(IntPtr);
ExceptionSelectorValue->setName("eh_selector");
- FuncEHPersonality = Intrinsic::getDeclaration(TheModule,
- (IntPtr == Type::getInt32Ty(Context) ?
- Intrinsic::eh_personality_i32 :
- Intrinsic::eh_personality_i64));
+ FuncEHLandingPad = Intrinsic::getDeclaration(TheModule,
+ (IntPtr == Type::getInt32Ty(Context) ?
+ Intrinsic::eh_landingpad_i32 :
+ Intrinsic::eh_landingpad_i64));
FuncEHException = Intrinsic::getDeclaration(TheModule,
Intrinsic::eh_exception);
@@ -1992,18 +1992,18 @@
} else {
tree catch_all_type = lang_eh_catch_all();
if (catch_all_type == NULL_TREE)
- // Use a C++ style null catch-all object.
- CatchAll = Constant::getNullValue(
- PointerType::getUnqual(Type::getInt8Ty(Context)));
+ // Use a C++ style null catch-all object.
+ CatchAll =
+ Constant::getNullValue(PointerType::getUnqual(Type::getInt8Ty(Context)));
else
- // This language has a type that catches all others.
- CatchAll = Emit(catch_all_type, 0);
+ // This language has a type that catches all others.
+ CatchAll = Emit(catch_all_type, 0);
}
Args.push_back(CatchAll);
- Value *EHType = Builder.CreateCall(FuncEHPersonality, Args.begin(),
- Args.end(), "eh_personality");
+ Value *EHType = Builder.CreateCall(FuncEHLandingPad, Args.begin(),
+ Args.end(), "eh_landingpad");
Builder.CreateStore(EHType, ExceptionSelectorValue);
// We'll use Args again.
@@ -2013,7 +2013,7 @@
foreach_reachable_handler(i, false, AddHandler, &Handlers);
for (std::vector<struct eh_region *>::iterator I = Handlers.begin(),
- E = Handlers.end(); I != E; ++I)
+ E = Handlers.end(); I != E; ++I)
getPostPad(get_eh_region_number(*I));
// Branch to the first handler...
@@ -2067,8 +2067,8 @@
PointerType::getUnqual(Type::getInt8Ty(Context)));
// Call get eh type id.
- // TODO: For now let's assume that this is a language specific
- // way of grabbing a type...
+ // TODO: For now let's assume that this is a language specific
+ // way of grabbing a type...
Value *TypeID = Builder.CreateCall(FuncEHGetTypeID, TType, "eh_typeid");
Value *Select = Builder.CreateLoad(ExceptionSelectorValue);
@@ -2155,7 +2155,7 @@
TARGET_ADJUST_LLVM_CC(CallingConvention, fntype);
CallInst *Call = Builder.CreateCall(DECL_LLVM(llvm_unwind_resume_libfunc),
- Arg);
+ Arg);
Call->setCallingConv(CallingConvention);
#else
Builder.CreateCall(DECL_LLVM(llvm_unwind_resume_libfunc), Arg);
@@ -3035,7 +3035,7 @@
if (DestLoc == 0) {
// Scalar to scalar copy.
assert(!isAggregateTreeType(TREE_TYPE(Op))
- && "Aggregate to scalar nop_expr!");
+ && "Aggregate to scalar nop_expr!");
Value *OpVal = Emit(Op, DestLoc);
if (Ty == Type::getVoidTy(Context)) return 0;
return CastToAnyType(OpVal, OpIsSigned, Ty, ExpIsSigned);
@@ -5762,7 +5762,7 @@
ReadWrite = 0;
} else if (cast<ConstantInt>(ReadWrite)->getZExtValue() > 1) {
warning (0, "invalid second argument to %<__builtin_prefetch%>;"
- " using zero");
+ " using zero");
ReadWrite = 0;
} else {
ReadWrite = Builder.getFolder().CreateIntCast(cast<Constant>(ReadWrite),
@@ -5899,8 +5899,8 @@
// FIXME: is i32 always enough here?
Result = Builder.CreateCall(Intrinsic::getDeclaration(TheModule,
- Intrinsic::eh_dwarf_cfa),
- ConstantInt::get(Type::getInt32Ty(Context), cfa_offset));
+ Intrinsic::eh_dwarf_cfa),
+ ConstantInt::get(Type::getInt32Ty(Context), cfa_offset));
return true;
}
@@ -5954,7 +5954,7 @@
Value *Handler = Emit(TREE_VALUE(TREE_CHAIN(arglist)), 0);
Intrinsic::ID IID = (IntPtr == Type::getInt32Ty(Context) ?
- Intrinsic::eh_return_i32 : Intrinsic::eh_return_i64);
+ Intrinsic::eh_return_i32 : Intrinsic::eh_return_i64);
Offset = Builder.CreateIntCast(Offset, IntPtr, true);
Handler = BitCastToType(Handler, PointerType::getUnqual(Type::getInt8Ty(Context)));
@@ -5963,7 +5963,7 @@
Args.push_back(Offset);
Args.push_back(Handler);
Builder.CreateCall(Intrinsic::getDeclaration(TheModule, IID),
- Args.begin(), Args.end());
+ Args.begin(), Args.end());
Result = Builder.CreateUnreachable();
EmitBlock(BasicBlock::Create(Context, ""));
Modified: llvm-gcc-4.2/branches/eh-experiment/gcc/llvm-internal.h
URL: http://llvm.org/viewvc/llvm-project/llvm-gcc-4.2/branches/eh-experiment/gcc/llvm-internal.h?rev=83126&r1=83125&r2=83126&view=diff
==============================================================================
--- llvm-gcc-4.2/branches/eh-experiment/gcc/llvm-internal.h (original)
+++ llvm-gcc-4.2/branches/eh-experiment/gcc/llvm-internal.h Tue Sep 29 19:21:11 2009
@@ -322,8 +322,8 @@
/// selector.
Value *ExceptionSelectorValue;
- /// FuncEHPersonality - Function used to mark catch all blocks
- Function *FuncEHPersonality;
+ /// FuncEHLandingPad - Function used to mark catch all blocks.
+ Function *FuncEHLandingPad;
/// FuncEHException - Function used to receive the exception.
Function *FuncEHException;
More information about the llvm-branch-commits
mailing list